==> jc-1.4.0.tar.gz: javax/xml/transform/dom/DOMSource.h <==
// public class javax.xml.transform.dom.DOMSource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 32d74a0b2d977dcf javax_xml_transform_dom_DOMSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_transform_dom_DOMSource_H_
#define _JC_javax_xml_transform_dom_DOMSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_javax_xml_transform_dom_DOMSource$sub_refs	_jc_javax_xml_transform_dom_DOMSource$sub_refs;
typedef struct _jc_javax_xml_transform_dom_DOMSource$sub_nonrefs	_jc_javax_xml_transform_dom_DOMSource$sub_nonrefs;
typedef struct _jc_javax_xml_transform_dom_DOMSource$refs	_jc_javax_xml_transform_dom_DOMSource$refs;
typedef struct _jc_javax_xml_transform_dom_DOMSource$nonrefs	_jc_javax_xml_transform_dom_DOMSource$nonrefs;
typedef struct _jc_javax_xml_transform_dom_DOMSource$object	_jc_javax_xml_transform_dom_DOMSource$object;

typedef struct _jc_javax_xml_transform_dom_DOMSource$fields_struct	_jc_javax_xml_transform_dom_DOMSource$fields_struct;
typedef const struct _jc_javax_xml_transform_dom_DOMSource$vmethods	_jc_javax_xml_transform_dom_DOMSource$vmethods;
typedef const struct _jc_javax_xml_transform_dom_DOMSource$vtable	_jc_javax_xml_transform_dom_DOMSource$vtable;
typedef const struct _jc_javax_xml_transform_dom_DOMSource$vtype	_jc_javax_xml_transform_dom_DOMSource$vtype;

// Class fields structure
struct _jc_javax_xml_transform_dom_DOMSource$fields_struct {
	struct _jc_java_lang_String$object	*FEATURE;
};
extern _jc_javax_xml_transform_dom_DOMSource$fields_struct _jc_javax_xml_transform_dom_DOMSource$class_fields;

// Constructors
extern void _jc_javax_xml_transform_dom_DOMSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *);
extern void _jc_javax_xml_transform_dom_DOMSource$method$_init$ea4cfa151ae11b7c(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_object *);
extern void _jc_javax_xml_transform_dom_DOMSource$method$_init$0e47427f47da5bb0(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_xml_transform_dom_DOMSource$method$getNode$07de3e4fb37034a1(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *);
extern struct _jc_java_lang_String$object *_jc_javax_xml_transform_dom_DOMSource$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *);
extern void _jc_javax_xml_transform_dom_DOMSource$method$setNode$a930c1aec668ba12(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_object *);
extern void _jc_javax_xml_transform_dom_DOMSource$method$setSystemId$2edffdaf6427879d(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_xml_transform_dom_DOMSource$method_info$getNode$07de3e4fb37034a1;
extern _jc_method _jc_javax_xml_transform_dom_DOMSource$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_javax_xml_transform_dom_DOMSource$method_info$setNode$a930c1aec668ba12;
extern _jc_method _jc_javax_xml_transform_dom_DOMSource$method_info$setSystemId$2edffdaf6427879d;

// Virtual methods structure
struct _jc_javax_xml_transform_dom_DOMSource$vmethods {
	struct _jc_object	*(*getNode$07de3e4fb37034a1)(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *);
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *);
	void	(*setNode$a930c1aec668ba12)(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_object *);
	void	(*setSystemId$2edffdaf6427879d)(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_javax_xml_transform_dom_DOMSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_transform_dom_DOMSource$vmethods	javax_xml_transform_dom_DOMSource;
};

// Vtype
struct _jc_javax_xml_transform_dom_DOMSource$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_dom_DOMSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_dom_DOMSource$sub_refs {
	struct _jc_object	*node;
	struct _jc_java_lang_String$object	*systemId;
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_dom_DOMSource$refs {
    _jc_javax_xml_transform_dom_DOMSource$sub_refs	javax_xml_transform_dom_DOMSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_dom_DOMSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_dom_DOMSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_transform_dom_DOMSource$sub_nonrefs	javax_xml_transform_dom_DOMSource;
};

// Object instance structure
struct _jc_javax_xml_transform_dom_DOMSource$object {
	_jc_javax_xml_transform_dom_DOMSource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_dom_DOMSource$vtype	*vtype;
	_jc_javax_xml_transform_dom_DOMSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_dom_DOMSource$vtype _jc_javax_xml_transform_dom_DOMSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_dom_DOMSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_dom_DOMSource$class_object;

#endif	/* _JC_javax_xml_transform_dom_DOMSource_H_ */

==> jc-1.4.6.tar.gz: javax/xml/transform/dom/DOMSource.h <==
// public class javax.xml.transform.dom.DOMSource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 32d74a0b2d977dcf javax_xml_transform_dom_DOMSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_transform_dom_DOMSource_H_
#define _JC_javax_xml_transform_dom_DOMSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_javax_xml_transform_dom_DOMSource$sub_refs	_jc_javax_xml_transform_dom_DOMSource$sub_refs;
typedef struct _jc_javax_xml_transform_dom_DOMSource$sub_nonrefs	_jc_javax_xml_transform_dom_DOMSource$sub_nonrefs;
typedef struct _jc_javax_xml_transform_dom_DOMSource$refs	_jc_javax_xml_transform_dom_DOMSource$refs;
typedef struct _jc_javax_xml_transform_dom_DOMSource$nonrefs	_jc_javax_xml_transform_dom_DOMSource$nonrefs;
typedef struct _jc_javax_xml_transform_dom_DOMSource$object	_jc_javax_xml_transform_dom_DOMSource$object;

typedef struct _jc_javax_xml_transform_dom_DOMSource$fields_struct	_jc_javax_xml_transform_dom_DOMSource$fields_struct;
typedef const struct _jc_javax_xml_transform_dom_DOMSource$vmethods	_jc_javax_xml_transform_dom_DOMSource$vmethods;
typedef const struct _jc_javax_xml_transform_dom_DOMSource$vtable	_jc_javax_xml_transform_dom_DOMSource$vtable;
typedef const struct _jc_javax_xml_transform_dom_DOMSource$vtype	_jc_javax_xml_transform_dom_DOMSource$vtype;

// Class fields structure
struct _jc_javax_xml_transform_dom_DOMSource$fields_struct {
	struct _jc_java_lang_String$object	*FEATURE;
};
extern _jc_javax_xml_transform_dom_DOMSource$fields_struct _jc_javax_xml_transform_dom_DOMSource$class_fields;

// Constructors
extern void _jc_javax_xml_transform_dom_DOMSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_dom_DOMSource$method$_init$ea4cfa151ae11b7c(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_dom_DOMSource$method$_init$0e47427f47da5bb0(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_xml_transform_dom_DOMSource$method$getNode$07de3e4fb37034a1(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_xml_transform_dom_DOMSource$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_dom_DOMSource$method$setNode$a930c1aec668ba12(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_dom_DOMSource$method$setSystemId$2edffdaf6427879d(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_xml_transform_dom_DOMSource$method_info$getNode$07de3e4fb37034a1;
extern _jc_method _jc_javax_xml_transform_dom_DOMSource$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_javax_xml_transform_dom_DOMSource$method_info$setNode$a930c1aec668ba12;
extern _jc_method _jc_javax_xml_transform_dom_DOMSource$method_info$setSystemId$2edffdaf6427879d;

// Virtual methods structure
struct _jc_javax_xml_transform_dom_DOMSource$vmethods {
	struct _jc_object	*(*getNode$07de3e4fb37034a1)(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *) _JC_JCNI_ATTR;
	void	(*setNode$a930c1aec668ba12)(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setSystemId$2edffdaf6427879d)(_jc_env *, struct _jc_javax_xml_transform_dom_DOMSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_xml_transform_dom_DOMSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_transform_dom_DOMSource$vmethods	javax_xml_transform_dom_DOMSource;
};

// Vtype
struct _jc_javax_xml_transform_dom_DOMSource$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_dom_DOMSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_dom_DOMSource$sub_refs {
	struct _jc_object	*node;
	struct _jc_java_lang_String$object	*systemId;
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_dom_DOMSource$refs {
    _jc_javax_xml_transform_dom_DOMSource$sub_refs	javax_xml_transform_dom_DOMSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_dom_DOMSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_dom_DOMSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_transform_dom_DOMSource$sub_nonrefs	javax_xml_transform_dom_DOMSource;
};

// Object instance structure
struct _jc_javax_xml_transform_dom_DOMSource$object {
	_jc_javax_xml_transform_dom_DOMSource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_dom_DOMSource$vtype	*vtype;
	_jc_javax_xml_transform_dom_DOMSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_dom_DOMSource$vtype _jc_javax_xml_transform_dom_DOMSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_dom_DOMSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_dom_DOMSource$class_object;

#endif	/* _JC_javax_xml_transform_dom_DOMSource_H_ */
